.. phoebusgen documentation master file, created by
   sphinx-quickstart on Thu Sep 30 13:07:09 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to phoebusgen's documentation!
======================================


The code of this project is on Github: `phoebusgen <https://github.com/tynanford/phoebusgen>`_

Phoebusgen can be downloded via pip, `see here <https://pypi.org/project/phoebusgen/>`_

Look at :doc:`the widget docs <source/phoebusgen.widget>` and :doc:`the screen docs <source/phoebusgen.screen>`.

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
